// The svg
var svg = d3.select('svg'),
  width = +svg.attr('width'),
  height = +svg.attr('height');

// Map and projection
var projection = d3
  .geoMercator()
  .scale(70)
  .center([0, 20])
  .translate([width / 2, height / 2]);
var path = d3.geoPath(projection);

// Data and color scale
var data = d3.map();

// Load external data and boot
d3.queue()
  .defer(
    d3.json,
    'https://raw.githubusercontent.com/holtzy/D3-graph-gallery/master/DATA/world.geojson',
  )
  .defer(
    d3.csv,
    'https://raw.githubusercontent.com/bepnye/CP341/main/world-data-2023.csv',
    function (d) {
      data.set(d.Country, +d['Birth Rate']);
    },
  )
  .await(ready);

function ready(error, topo) {
  var colorScale = d3
    .scaleLinear()
    .domain(d3.extent(data.values()))
    .range(['white', 'blue']);

  var events = [
    {
      name: 'Fairbanks',
      lat: 64.887709896644,
      long: -147.83961340981054,
    },
    {
      name: 'Boston',
      lat: 42.353449738483896,
      long: -71.1600322679733,
    },
    {
      name: 'Philly',
      lat: 39.95145084415182,
      long: -75.21130674486913,
    },
    {
      name: 'COS',
      lat: 38.85047567802433,
      long: -104.8228922699839,
    },
  ];

  var foo = [
    { x: 3, y: 2 },
    { x: 3, y: 8 },
    { x: 11, y: 4 },
  ];
  console.log(d3.map(foo, (d) => d.x).keys());

  // Draw the map
  svg
    .append('g')
    .selectAll('path')
    .data(topo.features)
    .enter()
    .append('path')
    // draw each country
    .attr('d', path)
    .attr('fill', function (d) {
      return colorScale(data.get(d.properties.name));
    });

  svg
    .append('g')
    .selectAll('circle')
    .data(events)
    .enter()
    .append('circle')
    .attr('cx', (d) => projection([d.long, d.lat])[0])
    .attr('cy', (d) => projection([d.long, d.lat])[1])
    .attr('r', 4)
    .attr('name', (d) => d.name);
  console.log(data);
}
